<?php

/**
* @brief Line based representation of received telegrams, used by monitord_output_manager
*
* Every table line holding received telegrams shown by monitord_output_manager are defined here
* @author Martin Diedrich (mdiedrich)
* @date $Date: 2010-01-02 20:59:06 +0100 (Sa, 02 Jan 2010) $
*/
class monitord_output_element {

	/**
	* @brief  Constructor, yet empty
	*
	* @author Martin Diedrich (mdiedrich)
	*/
	public function monitord_output_element() {
	}
	
	/**
	* @brief  Fills member array all_data, every index will be output by monitord_write_tableentry
	*
	* @author Martin Diedrich (mdiedrich)
	* @param $mysql_result_line_assoc Associative array from mysql_fetch_assoc holding a single database line/telegram
	*/
	public function set_all_data($mysql_result_line_assoc) {
		$this->all_data = $mysql_result_line_assoc;
	}
	
	/**
	* @brief Maps id, status, timecode etc. to human readable when reimplemented
	*
	* @author Martin Diedrich (mdiedrich)
	* @param $idx Index from associative array member all_data
	* @param $val Value from associative array member all_data
	* @param $myconfig Holds complete monitord_config.ini as array given by php function parse_ini()
	* @return Unchanged $val by default, mapped $val when reimplemented
	*/
	private function output_mappings($idx, $val, $myconfig) {
		return $val;
	}
	
	/**
	* @brief Writes table headings as given by member all_data's idexes
	*
	* @author Martin Diedrich (mdiedrich)
	*/
	public function monitord_write_tableheader() {
		echo '<tr>';
		foreach($this->all_data AS $idx => $val) {
			echo '<th>';
			echo ucfirst($idx);
			echo '</th>';
		}
		echo "</tr>\n";
	}
	
	/**
	* @brief Writes the table line's contents WITHOUT tr tags (inner HTML only)
	*
	* @author Martin Diedrich (mdiedrich)
	* @param $myconfig Holds complete monitord_config.ini as array given by php function parse_ini()
	* @param $linenum Actual line count as needed for giving the entry line an id to be changed by JavaScript (not implemented yet)
	* @return Table line entry (without tr tags, inner HTML only)
	*/
	public function monitord_write_tableentry($myconfig, $linenum) {
		$line = '';
		foreach($this->all_data AS $idx => $val) {
			$line .= '<td id="' . $idx . $linenum . '" class="' . $idx . '" style="' . $this->css_bgcolor_selector($idx, $val, $myconfig) . '">';
			if($val != null) {
				$line .= htmlentities($this->output_mappings($idx, $val, $myconfig));
			} else {
				$line .= '- - -';
			}
			$line .= '</td>';
		}
		return $line;
	}
	
	/**
	* @brief Selects background color for given index/val out of member all_data when reimplemented
	*
	* @author Martin Diedrich (mdiedrich)
	* @param $idx Index from associative array member all_data
	* @param $val Value from associative array member all_data
	* @param $myconfig Holds complete monitord_config.ini as array given by php function parse_ini()
	* @return null by default, css background tag when reimplemented
	*/
	protected function css_bgcolor_selector($idx, $val, $myconfig) {
		return null;
	}
	
}

?>