<?php

/**
* @brief Callsign based tableau, used by monitord_status_display_manager
*
* All tableaus shown by monitord_status_display_manager are defined here.
* @author Martin Diedrich (mdiedrich)
* @date $Date: 2010-04-22 14:15:17 +0200 (Do, 22 Apr 2010) $
*/
class monitord_status_display_element {

	function monitord_status_display_element($all_data, $monitord_ini) {
		$this->all_data = $all_data;
		$this->monitord_ini = $monitord_ini;
	}
	
	/**
	* @brief Writes down a box holding and showing all information given by status telegram
	*
	* @author Martin Diedrich (mdiedrich)
	*/
	function write_status_display_element() {
		echo '<div style="width:150px; height: 90px; float:left; border:1px solid; margin:20px; padding:20px; font-family:sans-serif; background-color:' . $this->monitord_ini['status_color']['status'. $this->all_data['status'] .'_fz'] . ';"><div style="font-weight:bold;">' . substr($this->all_data['kennung'], -4, 2) . ' / ' . substr($this->all_data['kennung'], -2, 2) . '</div><div style="float:right;" align="right">' . $this->all_data['status'] . '</div><div align="left" style="vertical-align:bottom; font-size:10px;">' . $this->get_fms_organisation(substr($this->all_data['kennung'], 0, 1)) . ' // ' . substr($this->all_data['kennung'], 1, 3) . '</div><div style="clear:both;font-size:11px;">' . $this->all_data['uhrzeit'] . '</div>' . (($this->all_data['status'] != 1 && $this->all_data['status'] != 2 && $this->all_data['status'] != 6) ? ('<div style="font-size:10px;">' . ($this->all_data['text'] != '' ? substr($this->all_data['text'], 0) : 'Keine Einsatzinformationen vorhanden') . '</div>') : '<div>Ohne Einsatz</div>') . '</div>';
	}

	/**
	* @brief "kennung" might be calculated to an organization such as DRK, Feuerwehr etc. - done herein
	*
	* @author Martin Diedrich (mdiedrich)
	*/
	function get_fms_organisation($orgs) {
		switch($orgs) {
				case 1 : return 'POL';
				case 2 : return 'BP';
				case 3 : return 'BKA';
				case 4 : return 'KAT';
				case 5 : return 'ZOL';
				case 6 : return 'FW';
				case 7 : return 'THW';
				case 8 : return 'ASB';
				case 9 : return 'DRK';
				case 'A' : return 'JUH';
				case 'B' : return 'MHD';
				case 'C' : return 'DLR';
				case 'D' : return 'RD';
				case 'E' : return 'ZVS';
				case 'F' : return 'FWI';
		}
	}
	
}

/**
* @brief Module to display received FMS status calls on callsign based tableaus
*
* This module shows received FMS status calls on big tableaus. Customizable by css style information and its respective ini-secion
* @author Martin Diedrich (mdiedrich)
* @date 12-2009
*/
class monitord_status_display_manager extends monitord_webfrontend_module {

	/**
	* @brief The module's main output method, fills main content part with colored boxes
	*
	* @author Martin Diedrich (mdiedrich)
	*/
	function output_content() {
		$query = $this->get_db_function();
		$result = mysql_query($query, $this->dbconn);
		if(!$result) {
			throw new exception('Database query failed:<br>' . mysql_error() . ':<br>&quot;' . $query . '&quot;', $this->monitord_ini['failcodes']['dbquery']);
		}
		if(mysql_affected_rows() == 0) {
			echo '<div class="info_400">Es befinden sich derzeit keine Eintr&auml;ge in der Datenbank,<br>die zu den Filterkriterien passen.</div>';
		} else {
			while($res = mysql_fetch_assoc($result)) {
				$tmp_display_element = new monitord_status_display_element($res, $this->monitord_ini);
				$tmp_display_element->write_status_display_element();
				echo "\n";
			}
			echo '<p style="font-size:12px;clear:both;text-align:right;color:#000080;">Die Anzeige zeigt nur die letzten als FMS-Telegramm ausgesendeten Statusmeldungen an!<br>Momentanes Zeitfenster: ' . $this->module_ini['main']['past_hrs'] . ' Stunden</p>';
			$this->write_legend();
		}
	}
	
	/**
	* @brief Generates SQL-Query for its qiven type or purpose (here: FMS status telegrams)
	*
	* @author Martin Diedrich (mdiedrich)
	*/
	function get_db_function() {
		if(false) {
			return "SELECT id, kennung, status, uhrzeit, beschreibung FROM (SELECT max(id) AS id, kennung, SUBSTRING(kennung, 1, 1) AS orgs, SUBSTRING(kennung, 5, 2) AS ortk, SUBSTRING(kennung, 7, 2) AS fzgk FROM monitord_fms WHERE kennung REGEXP '[0-9A-F]{1}" . mysql_real_escape_string($this->module_ini['main']['region']) . "[0-9A-F]{4}' AND richtung = '0' AND status < 10 AND uhrzeit > DATE_SUB(now(), INTERVAL " . mysql_real_escape_string($this->module_ini['main']['past_hrs']) .  " HOUR) GROUP BY kennung ORDER BY ortk ASC, fzgk ASC) kid LEFT JOIN monitord_fms USING (id, kennung) LEFT JOIN monitord_mappings USING (kennung) ORDER BY kennung DESC"; 
		} else {
			return "SELECT id, kennung, status, uhrzeit, beschreibung, tmp1.text FROM (SELECT max(id) AS id, kennung, SUBSTRING(kennung, 1, 1) AS orgs, SUBSTRING(kennung, 5, 2) AS ortk, SUBSTRING(kennung, 7, 2) AS fzgk FROM monitord_fms WHERE kennung REGEXP '[0-9A-F]{1}" . mysql_real_escape_string($this->module_ini['main']['region']) . "[0-9A-F]{4}' AND richtung = '0' AND status < 10 AND uhrzeit > DATE_SUB(now(), INTERVAL " . mysql_real_escape_string($this->module_ini['main']['past_hrs']) .  " HOUR) GROUP BY kennung ORDER BY ortk ASC, fzgk ASC) kid LEFT JOIN monitord_fms USING (id, kennung) LEFT JOIN monitord_mappings USING (kennung) LEFT JOIN (SELECT kennung, text FROM (SELECT max(id) AS id FROM monitord_fms fms WHERE status = 10 AND richtung = 1 GROUP BY kennung) tmp1 LEFT JOIN monitord_fms USING(id)) tmp1 USING (kennung)";
		}
	}
	
	/**
	* @brief writes a legend telling status - plain text
	*
	* @author Martin Diedrich (mdiedrich)
	*/
	function write_legend() {
		echo '<table style="font-size:12px;">';
		echo '<tr>' . "\n";
		echo '<td style="border:1px solid;padding:2px;background:' . $this->monitord_ini['status_color']['status1_fz'] . '">1 - Frei auf Funk</td>';
		echo '<td style="border:1px solid;padding:2px;background:' . $this->monitord_ini['status_color']['status2_fz'] . '">2 - Frei an Wache</td>';
		echo '<td style="border:1px solid;padding:2px;background:' . $this->monitord_ini['status_color']['status3_fz'] . '">3 - Einsatz &uuml;bernommen</td>';
		echo '<td style="border:1px solid;padding:2px;background:' . $this->monitord_ini['status_color']['status4_fz'] . '">4 - Am Einsatzort</td>';
		echo '<td style="border:1px solid;padding:2px;background:' . $this->monitord_ini['status_color']['status5_fz'] . '">5 - Sprechwunsch</td>';
		echo '<td style="border:1px solid;padding:2px;background:' . $this->monitord_ini['status_color']['status6_fz'] . '">6 - Nicht einsatzbereit</td>';
		echo '<td style="border:1px solid;padding:2px;background:' . $this->monitord_ini['status_color']['status7_fz'] . '">7 - Mit Patient zum KH</td>';
		echo '<td style="border:1px solid;padding:2px;background:' . $this->monitord_ini['status_color']['status8_fz'] . '">8 - Am Krankenhaus</td>';
		echo '</tr>' . "\n";
		echo '</table>' . "\n\n";
	}
	
	/**
	* @brief Module initialization
	*
	* @author Martin Diedrich (mdiedrich)
	*/
	function initialize() {
		$this->moduletitle = "Statusdisplay";
		$this->revision = '$Revision: 427 $';
		$this->date = '$Date: 2010-04-22 14:15:17 +0200 (Do, 22 Apr 2010) $';
	}

}

?>